@@ -16,13 +16,14 @@ import urllib
 import gobject
 import socket
 import re
+import os.path
 from gconf import client_get_default
 from urllib2 import URLError
 from ziggy.languages import Languages
 from ziggy.state import AppState
 from baas.core.plugins import PluginLoader
 from baas.core.helpers import strip_tags, htmlentities_decode, xmlify
-from gtk import set_application_name, HBox, VBox, Label, Dialog, gdk, TextBuffer, Table, ListStore, CellRendererText, TreeViewColumn, main_quit
+from gtk import set_application_name, HBox, VBox, Label, Dialog, gdk, Image, TextBuffer, Table, ListStore, CellRendererText, TreeViewColumn, main_quit
 from gtk import DIALOG_MODAL, DIALOG_DESTROY_WITH_PARENT, STOCK_NO, RESPONSE_REJECT, STOCK_OK, RESPONSE_ACCEPT, HILDON_UI_MODE_NORMAL
 from gtk import HILDON_SIZE_THUMB_HEIGHT, HILDON_SIZE_AUTO_HEIGHT, HILDON_SIZE_AUTO_WIDTH, HILDON_SIZE_FINGER_HEIGHT, WRAP_WORD
 from gtk import FILL, EXPAND, JUSTIFY_LEFT
@@ -33,6 +34,8 @@ from hildon import  BUTTON_ARRANGEMENT_VERTICAL, BUTTON_ARRANGEMENT_HORIZONTAL,
 timeout = 8
 socket.setdefaulttimeout(timeout)
 
+icon_dir = os.path.dirname(__file__)+'/icons/'
+
 pluginHnd = PluginLoader(config=False,format="raw")
 pluginHnd.load_plugins()
 pluginHnd.load_map()
@@ -126,9 +129,13 @@ class BaasGui(object):
             height = HILDON_SIZE_AUTO_HEIGHT
         for service in self.state.services:
             if service not in self.state.services_active:
-                continue
+                continue            
             button = GtkButton(HILDON_SIZE_AUTO_WIDTH | height)
-            button.set_label(wording.get(service, service))
+            img = Image()
+            img.set_from_file(icon_dir+service+'.png')
+            button.set_label('  '+wording.get(service, service))
+            button.set_image(img)
+            button.set_alignment(0.0, 0.5)
             button.connect("clicked", self.show_service_window, service)
             services_box.pack_start(button, True, True, 0)
             button.show()
@@ -266,6 +273,13 @@ class BaasGui(object):
         pbutton.set_active(self.state.use_proxy)
         pbutton.connect("toggled", self.menu_settings_toggled, 'use_proxy')
 
+        # service check button
+        mbutton = CheckButton(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT)
+        mbutton.set_label('use google mobilizer to open webpages')
+        mbutton.set_size_request(750, 70)
+        mbutton.set_active(self.state.mobilizer)
+        mbutton.connect("toggled", self.menu_settings_toggled, 'mobilizer')
+        
         # history len
         len_box = self.menu_select_history_len()
 
@@ -273,6 +287,7 @@ class BaasGui(object):
         box2.pack_start(len_box, False, False, 5)
         box2.pack_start(lbutton, True, True, 5)
         box2.pack_start(pbutton, True, True, 5)
+        box2.pack_start(mbutton, True, True, 5)
 
         self.settings_dialog.action_area.add(box2)
         self.settings_dialog.show_all()
@@ -1153,9 +1168,11 @@ class BaasGui(object):
     def modify_result_link(self, link):
         try:
             if self.input_command == 'maemo' and link.find('showthread.php?') >= 0:
-                link += '&highlight='+urllib.quote_plus(self.input_buffer.strip().encode('latin-1'))
+                link += '&highlight='+urllib.quote_plus(self.input_buffer.strip().encode('latin-1'))                
+            if self.state.mobilizer:
+                link = 'http://google.com/gwt/x?u=%s' % urllib.quote_plus(link)
         except:
-            pass
+            pass        
         return link
         
     def parse_term(self, term):
