@@ -21,6 +21,7 @@ class AppState(object):
         self.deli_pop = 0
         self.direct_linkage = False
         self.use_proxy = False
+        self.mobilizer = False
         self.history_len = 10
         self.buffers = {}
         self.langs = {}
@@ -63,6 +64,7 @@ class AppState(object):
             self.history = data.get('history',{})
             self.direct_linkage = data.get('direct_linkage', self.direct_linkage)
             self.use_proxy = data.get('use_proxy', self.use_proxy)
+            self.mobilizer = data.get('mobilizer', self.mobilizer)
             self.history_len = data.get('history_len', self.history_len)
             self.default_langs = data.get('default_langs', {})
             self.services_active = data.get('services_active',self.services_active) 
@@ -74,9 +76,10 @@ class AppState(object):
         
     def save(self):
         state = {
-            'history':self.history, 'history_len': self.history_len, 'services_active': self.services_active, 
-            'services':self.services, 'direct_linkage': self.direct_linkage, 'use_proxy':self.use_proxy, 
-            'default_langs': self.default_langs,}
+            'history':self.history, 'history_len': self.history_len,
+            'services_active': self.services_active,  'services':self.services,
+            'direct_linkage': self.direct_linkage, 'use_proxy':self.use_proxy, 
+            'default_langs': self.default_langs, 'mobilizer':self.mobilizer}
         f = open(self.config_file,'w')
         simplejson.dump(state, f)
         f.close()
